require("factsheet")
local heat_processing_tech = {
	type = "technology",
	name = "adamo-heat-processing",
	icon = "__adamo-cinefaction__/thumbnail.png",
	icon_size = 128,
	prerequisites = {
		"advanced-material-processing",
		"fluid-handling"
	},
	unit = {
		count = 100,
		ingredients = {{
				"automation-science-pack",
				1
			},{
				"logistic-science-pack",
				1				
		}},
		time = 30
	},
    effects = {{
    		type = "unlock-recipe",
    		recipe = "heat-pipe"
    	},{
    		type = "unlock-recipe",
    		recipe = "heat-exchanger"
    	},{
    		type = "unlock-recipe",
    		recipe = "adamo-cinefaction-heatpump"

    	},{
    		type = "unlock-recipe",
    		recipe = "adamo-cinefaction-reaction-kettle"
	}},
	order = "d-a"
}
data:extend({
	heat_processing_tech
})

local reaction_kettle_item = {
	type = "item",
	name = "adamo-cinefaction-reaction-kettle",
	icon = "__adamo-cinefaction__/graphics/icons/reaction-kettle.png",
	icon_size = 32,
	group = "production",
	subgroup = "production-machine",
	order = "e[adamo-cinefaction-reaction-kettle]",
	place_result = "adamo-cinefaction-reaction-kettle",
	stack_size = 50
}
local reaction_kettle_recipe = {
	type = "recipe",
	name = "adamo-cinefaction-reaction-kettle",
	enabled = false,
	ingredients = 
	{
		{"heat-pipe",1},
		{"pipe",1},
		{"stone-brick",1},
	},
	result = "adamo-cinefaction-reaction-kettle"
}
local reaction_kettle_entity = {
	type = "assembling-machine",
	name = "adamo-cinefaction-reaction-kettle",
	gui_title_key = "adamo-cinefaction-reaction-kettle",
	has_backer_name = true,
	icon = "__adamo-cinefaction__/graphics/icons/reaction-kettle.png",
	icon_size = 32,
	flags = {"placeable-player", "player-creation"},
	crafting_categories = {
		"chemistry",
	},
	ingredient_count = 1,
	result_inventory_size = 0,
	minable = {
		mining_time = 0.2,
		result = "adamo-cinefaction-reaction-kettle"
	},
	max_health = 150,
	crafting_speed = 3,
	energy_usage = "250kW",
	corpse = "small-remnants",
	resistances = {{
			type = "fire",
			percent = 80
	}},
	working_sound = {
    	sound = {
    		filename = "__base__/sound/chemical-plant.ogg",
    		volume = 0.6
    	},
    },
	fast_replaceable_group = "pipe",
	collision_box = {{-0.49, -0.49}, {0.49, 0.49}},
	selection_box = {{-0.5, -0.5}, {0.5, 0.5}},
	fluid_boxes = {{
			production_type = "input",
			pipe_connections = {
				{type = "input-output", position={1,0}},
			},
			pipe_picture = bulkypipepictures(),
			pipe_covers = pipecoverspictures(),
			secondary_draw_orders = {
				north=-1,south=-1,east=-1,west=-1
			}
		},{
			production_type = "input",
			pipe_connections = {
				{type = "input-output", position={-1,0}},
			},
			pipe_picture = bulkypipepictures(),
			pipe_covers = pipecoverspictures(),
			secondary_draw_orders = {
				north=-1,south=-1,east=-1,west=-1
			}
		},{
			production_type = "input",
			pipe_connections = {
				{type = "input-output", position={0,1}}
			},
			pipe_picture = bulkypipepictures(),
			pipe_covers = pipecoverspictures(),
			secondary_draw_orders = {
				north=-1,south=-1,east=-1,west=-1
			}
		},{
			production_type = "output",
			base_level = 1,
			pipe_connections = {
				{position={0,-1}}
			},
			pipe_picture = bulkypipepictures(),
			pipe_covers = pipecoverspictures(),
			secondary_draw_orders = {
				north=-1,south=-1,east=-1,west=-1
			}
		},
		off_when_no_fluid_recipe = true
	},
	energy_source = {
		type = "heat",
		emissions_per_minute = 0.1,
		max_temperature = 500,
		specific_heat = "25kJ",
		max_transfer = "1GW",
		min_working_temperature = 200,
		connections = {{
				position = {0,0},
				direction = defines.direction.north
			},{
				position = {0,0},
				direction = defines.direction.east
			},{
				position = {0,0},
				direction = defines.direction.west
			},{
				position = {0,0},
				direction = defines.direction.south
		}},
		pipe_covers = make_4way_animation_from_spritesheet({
				filename = 
					"__base__/graphics/entity/"
					.."heat-exchanger/heatex-endings.png",
				line_length = 4,
				width = 32,
				height = 32,
				direction_count = 4,
				hr_version = {
					filename = 
						"__base__/graphics/entity/"
						.."heat-exchanger/hr-heatex-endings.png",
					line_length = 4,
					width = 64,
					height = 64,
					direction_count = 4,
					scale = 0.5
				}
		})
	},
	animation = {
		filename =
			"__adamo-cinefaction__/graphics/entity/reaction-kettle.png",
		priority = "extra-high",
		width = 50,
		height = 50,
		shift = {0.24, 0.1875}
	},
	working_visualisations = {{
			render_layer = "lower-object-above-shadow",
			effect = "uranium-glow",
			fadeout = true,
			animation = {
				filename =
					"__base__/graphics/entity/"
					.."small-lamp/hr-lamp-light.png",
				frame_count = 1,
				height = 78,
				width = 90,
				scale = 0.85,
				shift = {-0.025,0.1},
				tint = colors.heating_element_core,
				flags = {"light"}
			}
		},{
			effect = "uranium-glow",
			light = {
				intensity = 0.5,
				size = 3,
				color = colors.heating_element_glow,
				shift = {0,0.25}
			}
	}}
}
data:extend({
	reaction_kettle_recipe,
	reaction_kettle_item,
	reaction_kettle_entity
})

local still_item = {
	type = "item",
	name = "adamo-cinefaction-still",
	icon = "__adamo-cinefaction__/graphics/icons/still.png",
	icon_size = 32,
	subgroup = "production-machine",
	order = "d[adamo-cinefaction-still]",
	place_result = "adamo-cinefaction-still",
	stack_size = 10
}
local still_recipe = {
	type = "recipe",
	name = "adamo-cinefaction-still",
	energy_required = 2,
	enabled = false,
	ingredients = {
		{"wood", 5},
		{"pipe", 5},
		{"stone-brick", 5}
	},
	result = "adamo-cinefaction-still"
}
function stillpipepictures()
	return {
 		east = {
			filename =
				"__adamo-cinefaction__/graphics/"
				.."connections/washer-pipe-e.png",
			priority = "high",
			width = 256,
			height = 256,
			shift = {-1.78, -0.05},
			scale = 0.5
		},
	 	west = {
			filename =
				"__adamo-cinefaction__/graphics/"
				.."connections/washer-pipe-w.png",
			priority = "high",
			width = 256,
			height = 256,
			shift = {2.33, -0.041},
			scale = 0.5
		},
		north = {
			filename =
				"__adamo-cinefaction__/graphics/"
				.."connections/washer-pipe-n.png",
			priority = "extra-high",
			width = 256,
			height = 256,
			shift = {0.278, 2},
			scale = 0.5
 		},
		south = {
			filename =
				"__adamo-cinefaction__/graphics/"
				.."connections/washer-pipe-s.png",
			priority = "high",
			width = 256,
			height = 256,
			shift = {0.27, -2},
			scale = 0.5
		},
	}
end
local still_entity = {
    type = "assembling-machine",
	name = "adamo-cinefaction-still",
	gui_title_key = "adamo-cinefaction-still",
	has_backer_name = true,
	icon = "__adamo-cinefaction__/graphics/icons/still.png",
	icon_size = 32,
	flags = {
		"placeable-neutral",
		"placeable-player",
		"player-creation"
	},
	minable = {
		hardness = 0.2,
		mining_time = 1.5,
		result = "adamo-cinefaction-still"
	},
	max_health = 300,
	corpse = "medium-remnants",
	resistances = {{type = "fire",percent = 70}},
	collision_box = {{-1.4, -1.4}, {1.4, 1.4}},
	selection_box = {{-1.5, -1.5}, {1.5, 1.5}},	
	crafting_categories = {"oil-processing"},
	energy_usage = "300kW",
	ingredient_count = 0,
	crafting_speed = 1,
	energy_source ={
		type = "burner",
		fuel_category = "chemical",
		fuel_inventory_size = 1,
		emissions_per_minute = 2,
		smoke = {{
				name = "smoke",
				height = 1.9,
				deviation = {0.1, 0.1},
				frequency = 7
		}},
	},
	fast_replaceable_group = "assembling-machine",
	module_specification = {
		module_slots = 2
	},
	allowed_effects = {
		"consumption",
		"speed",
		"productivity",
		"pollution"
	},
	fluid_boxes = {{
			production_type = "input",
			pipe_connections = {{
					position={0,2},
					max_underground_distance = 5
			},{
					position={0,-2},
					max_underground_distance = 5
			}},
			base_level = -1,
			secondary_draw_orders = {
				north = -2,
				south = -2,
				east = -2,
				west = -2,
			},
		},{
			production_type = "input",
			pipe_picture = stillpipepictures(),
			pipe_covers = pipecoverspictures(),
			base_level = -1,
			pipe_connections = {
				{position={0,-2}},
			},
			secondary_draw_orders = {
				north = -1,
				east = -1,
				west = -1
			},
		},{
			production_type = "output",
			pipe_picture = stillpipepictures(),
			pipe_covers = pipecoverspictures(),
			base_level = 1,
			pipe_connections = {
				{position={2,0}},
			},
			secondary_draw_orders = {
				north = -1,
				east = -1,
				west = -1
			},
		},{
			production_type = "output",
			pipe_picture = stillpipepictures(),
			pipe_covers = pipecoverspictures(),
			base_level = 1,
			pipe_connections = {
				{position={0,2}},
			},
			secondary_draw_orders = {
				north = -1,
				east = -1,
				west = -1
			},
		},{
			production_type = "output",
			pipe_picture = stillpipepictures(),
			pipe_covers = pipecoverspictures(),
			base_level = 1,
			pipe_connections = {
				{position={-2,0}},
			},
			secondary_draw_orders = {
				north = -1,
				east = -1,
				west = -1
			},
		},
		off_when_no_fluid_recipe = true
	},
	working_sound = {
		sound = {{
				filename = "__base__/sound/oil-refinery.ogg",
				volume = 0.8
		}},
		idle_sound = {
    		filename = "__base__/sound/idle1.ogg",
    		volume = 0.6
    	},
    	apparent_volume = 1,
	},
	animation = {
		filename = "__adamo-cinefaction__/graphics/entity/still.png",
		width = 320, height = 320,
		shift = {0.49, -0.46},
		scale = 0.5,
		frame_count = 16,
		line_length = 4,
		animation_speed = 1.0
	}
}
data:extend({
	still_recipe,
	still_item,
	still_entity
})
add_recipe_to_tech(
	"fluid-handling",
	"adamo-cinefaction-still"
)

local heatsource_item = {
	type = "item",
	name = "adamo-cinefaction-heatpump",
	icon = "__adamo-cinefaction__/graphics/icons/heatpump.png",
	icon_size = 32,
	subgroup = "energy",
	order = "f[heat-energy]-a[adamo-cinefaction-heatpump]",
	place_result = "adamo-cinefaction-heatpump",
	stack_size = 10
}
local heatsource_recipe = {
	type = "recipe",
	name = "adamo-cinefaction-heatpump",
	energy_required = 5,
	enabled = false,
	ingredients = 
	{
		{"steel-plate",20},
		{"stone-brick",5},
		{"heat-pipe",5},
	},
	result = "adamo-cinefaction-heatpump"
}

local heatsource_entity = {
	type = "reactor",
	name = "adamo-cinefaction-heatpump",
	has_backer_name = true,
	icon = "__adamo-cinefaction__/graphics/icons/heatpump.png",
	icon_size = 32,
	flags = {"placeable-neutral", "placeable-player", "player-creation"},
	minable = {mining_time = 2, result = "adamo-cinefaction-heatpump"},
	max_health = 500,
	corpse = "medium-remnants",
	neighbour_bonus = 0,
	neighbour_collision_increase = 0,
	scale_energy_usage = true,
	open_sound = {
		filename = "__base__/sound/machine-open.ogg",
		volume = 0.85
	},
	close_sound = {
		filename = "__base__/sound/machine-close.ogg",
		volume = 0.75
	},
    working_sound ={
		sound = { filename = "__base__/sound/electric-furnace.ogg" }
	},
	resistances = {{
			type = "fire",
			percent = 80
	}},
    collision_box = {{-1.2, -1.2}, {1.2, 1.2}},
	selection_box = {{-1.5, -1.5}, {1.5, 1.5}},	
    consumption = "20MW",
	energy_source = {
		type = "burner",
		fuel_inventory_size = 4,
		burnt_inventory_size = 1,
		smoke = {{
				name = "smoke",
				position = {0.0,-0.7},
				frequency = 25,
				starting_vertical_speed = 0.06,
				deviation = {0.08,-0.06}
			},{
				name = "smoke",
				position = {0.0,-0.1},
				frequency = 25,
				starting_vertical_speed = 0.06,
				deviation = {0.08,-0.06}
		}},
		light_flicker = {
			color = colors.heating_element_glow,
			maximum_intensity = 0.5
		},
		render_no_power_icon = false,
		emissions_per_minute = 30,
	},
	heat_buffer = {
		max_temperature = 510,
		specific_heat = "1MJ",
		max_transfer = "10GW",
		connections = {{
				position = {0, -1},
				direction = defines.direction.north
			},{
				position = {0,1},
				direction = defines.direction.south
			},{
				position = {-1, 0},
				direction = defines.direction.west
			},{
				position = {1, 0},
				direction = defines.direction.east
		}}
	},
	picture = {
			filename = 
				"__adamo-cinefaction__/graphics/entity/heatpump.png",
			priority = "extra-high",
			width = 256,
			height = 256,
			shift = {0.3125, -0.15625 },
			scale = 0.5,						
	},
	working_light_picture = {
		filename =
			"__adamo-cinefaction__/graphics/entity/heatpump-lights.png",
		width = 256,
		height = 256,
		shift = {0.3125, -0.15625 },
		scale = 0.5,
    },
	connection_patches_connected = {
		sheet = {
			filename =
				"__base__/graphics/entity/nuclear-reactor/"
				.."reactor-connect-patches.png",
			width = 32,
			height = 32,
			variation_count = 12,
			hr_version = {
				filename = 
					"__base__/graphics/entity/nuclear-reactor/"
					.."hr-reactor-connect-patches.png",
				width = 64,
				height = 64,
				variation_count = 12,
				scale = 0.5
			}
		}
	},
	connection_patches_disconnected = {
		sheet = {
			filename = 
				"__base__/graphics/entity/nuclear-reactor/"
				.."reactor-connect-patches.png",
			width = 32,
			height = 32,
			variation_count = 12,
			--y = 32,
			hr_version = {
				filename = 
					"__base__/graphics/entity/nuclear-reactor/"
					.."hr-reactor-connect-patches.png",
				width = 64,
				height = 64,
				variation_count = 12,
				y = 64,
				scale = 0.5
			}
		}
	},
}
data:extend({
	heatsource_recipe,
	heatsource_item,
	heatsource_entity
})